run_local

Function run_local 

pub fn run_local(
    verbose: bool,
    _fallback: bool,
    force: bool,
    frozen: bool,
) -> Result<()>
Performs a project-local sync of registries.

In Specification v2, projects can have their own isolated package databases stored in ./.zoi/pkgs/db. This ensures that a project’s dependencies are reproducible and independent of the user’s global registry state.